<p align="center">
  <img src="https://github.com/LorenzoPiu/Images/blob/main/Logo-0.0.8.png" width="35%">
</p>

#

A Python package to process combustion DNS.

## Installation

Run the following command to install:

```python
pip install aPrioriDNS
```

This will automatically install or update the following dependencies if necessary:

- numpy>=1.18.0,
- scipy>=1.12.0,
- matplotlib>=3.2.0,
- cantera>=3.0.0,
- tabulate>=0.9.0,
- requests>=2.32.0.

## Documentation

The complete software documentation is available at: 

https://apriori.gitbook.io/apriori-documentation-1
